# Preparing Inputs

This section explains how to prepare input sequences for STACIE to ensure high-quality results.
It consists of three parts:

- Guidelines for planning and preparing [sufficient input sequences](data_sufficiency.md) for STACIE.
- Instructions for efficiently storing sequences on disk using [block averages](block_averages.md).
- Recommendations for performing [molecular dynamics](molecular_dynamics.md) simulations
  that generate suitable inputs for STACIE.

```{toctree}
:hidden:

data_sufficiency.md
block_averages.md
molecular_dynamics.md
```
